@@ -262,7 +262,7 @@ def set_model_params(X, y):
     return model
 
 
-def what_does_the_robot_say(filename="model_weights_saved.hdf5", model, chars):
+def what_does_the_robot_say(model, chars,filename="model_weights_saved.hdf5"):
     model.load_weights(filename)
     model.compile(loss='categorical_crossentropy', optimizer='adam')
     num_to_char = dict((i, c) for i, c in enumerate(chars))
